.. _aloe: https://github.com/aloetesting/aloe
.. _gherkin: https://cucumber.io/
.. _nose: https://nose.readthedocs.io/
.. _`Attribute selector plugin`: https://nose.readthedocs.io/en/latest/plugins/attrib.html
.. _lettuce: http://lettuce.it/
.. _`Gherkin syntax`: https://cucumber.io/docs/reference
.. _`aloe_django`: https://aloe.readthedocs.io/projects/aloe-django/
.. _`aloe_webdriver`: https://aloe.readthedocs.io/projects/aloe-webdriver/
